# Generated by roxygen2: do not edit by hand

export(DPA)
export(FEA)
export(GRN)
export(GSEA)
export(LPA)
export(PRA)
export(URA)
export(getDataGEO)
export(getDataTCGA)
export(moonlight)
export(plotCircos)
export(plotFEA)
export(plotNetworkHive)
export(plotURA)
import(Biobase)
import(HiveR)
import(RISmed)
import(SummarizedExperiment)
import(doParallel)
import(foreach)
importFrom(DOSE,gseDO)
importFrom(DOSE,simplot)
importFrom(GEOquery,getGEO)
importFrom(RColorBrewer,brewer.pal)
importFrom(TCGAbiolinks,GDCdownload)
importFrom(TCGAbiolinks,GDCprepare)
importFrom(TCGAbiolinks,GDCquery)
importFrom(TCGAbiolinks,GDCquery_clinic)
importFrom(TCGAbiolinks,TCGAanalyze_DEA)
importFrom(TCGAbiolinks,TCGAanalyze_DMC)
importFrom(TCGAbiolinks,TCGAanalyze_Filtering)
importFrom(TCGAbiolinks,TCGAanalyze_Normalization)
importFrom(TCGAbiolinks,TCGAanalyze_Preprocessing)
importFrom(TCGAbiolinks,TCGAquery_SampleTypes)
importFrom(TCGAbiolinks,TCGAquery_subtype)
importFrom(circlize,circlize)
importFrom(circlize,circos.clear)
importFrom(circlize,circos.initialize)
importFrom(circlize,circos.par)
importFrom(circlize,circos.rect)
importFrom(circlize,circos.text)
importFrom(circlize,circos.trackPlotRegion)
importFrom(circlize,get.cell.meta.data)
importFrom(clusterProfiler,bitr)
importFrom(gplots,heatmap.2)
importFrom(gplots,redblue)
importFrom(grDevices,dev.list)
importFrom(grDevices,dev.off)
importFrom(grDevices,graphics.off)
importFrom(grDevices,pdf)
importFrom(grDevices,rainbow)
importFrom(grDevices,rgb)
importFrom(graphics,barplot)
importFrom(graphics,legend)
importFrom(graphics,par)
importFrom(graphics,plot.new)
importFrom(graphics,text)
importFrom(grid,gpar)
importFrom(limma,contrasts.fit)
importFrom(limma,eBayes)
importFrom(limma,lmFit)
importFrom(limma,makeContrasts)
importFrom(limma,topTable)
importFrom(parmigene,knnmi.cross)
importFrom(randomForest,randomForest)
importFrom(stats,fisher.test)
importFrom(stats,model.matrix)
importFrom(stats,p.adjust)
importFrom(stats,quantile)
importFrom(utils,as.roman)
importFrom(utils,data)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
